import bb.cascades 1.4
import "Globals.js" as Globals

Page {
    property bool menuEnabled: false
    
    titleBar: TitleBar {
        title: qsTr("About", "Title of the About page") + Retranslate.onLocaleOrLanguageChanged
    }

    actions: [
        ActionItem {
            title: qsTr("Support", "A button/action to write an email to the application developer") + Retranslate.onLocaleOrLanguageChanged
            imageSource: "asset:///images/ic_email.png"
            ActionBar.placement: ActionBarPlacement.OnBar
            onTriggered: {
                _app.invokeEmailComposer(
                    Globals.feedbackEmail, 
                    qsTr("AppNinja (v%1) - Support request", "Subject line for support email. %1 is the version number").arg(Application.applicationVersion), 
                    "\n\n" + _app.getPlatformDescription());
            }
        },
        ActionItem {
            title: qsTr("Review", "A button/action to write a review for AppNinja in BlackBerry World") + Retranslate.onLocaleOrLanguageChanged
            imageSource: "asset:///images/ic_rate_app.png"
            ActionBar.placement: ActionBarPlacement.Signature
            onTriggered: {
                selfReviewInvocation.trigger(selfReviewInvocation.query.invokeActionId);
            }
        }
    ]

    ScrollView {
        scrollRole: ScrollRole.Main
        horizontalAlignment: HorizontalAlignment.Fill
        verticalAlignment: VerticalAlignment.Fill
        Container {
            horizontalAlignment: HorizontalAlignment.Fill
            leftPadding: ui.du(2)
            rightPadding: ui.du(2)
            topPadding: ui.du(2)
            bottomPadding: ui.du(2)
            Label {
                text: qsTr("AppNinja", "App name, do not translate") + Retranslate.onLocaleOrLanguageChanged
                textStyle.base: SystemDefaults.TextStyles.BigText
                horizontalAlignment: HorizontalAlignment.Center
            }
            Label {
                text: qsTr("Version %1", "Application version in 'About' screen").arg(_app.applicationVersion) + Retranslate.onLocaleOrLanguageChanged
                textStyle.base: SystemDefaults.TextStyles.BodyText
                horizontalAlignment: HorizontalAlignment.Center
            }
            Label {
                text: qsTr("\u00A92015 Andrei Popleteev", "Developer name, do not translate") + Retranslate.onLocaleOrLanguageChanged
                textStyle.base: SystemDefaults.TextStyles.BodyText
                horizontalAlignment: HorizontalAlignment.Center
            }
            Divider {
                topMargin: ui.du(2)
                bottomMargin: ui.du(2)
            }
            Label {
                text: qsTr("Credits", "Title of text section with acknowledgements and licensing terms of used components.") + Retranslate.onLocaleOrLanguageChanged
                textStyle.base: SystemDefaults.TextStyles.TitleText
                horizontalAlignment: HorizontalAlignment.Left
            }
            Label {
                text: qsTr("AppNinja was inspired by the <a href='appworld://content/59950807'>File System</a> app by <a href='appworld://vendor/70290'>Roger Leblanc (CellNinja)</a>.", "Content of the 'Credits' help section. Please also add your name like 'German/Italian/Chinese/... translation by YourNameHere'.") + Retranslate.onLocaleOrLanguageChanged 
                multiline: true
                textFormat: TextFormat.Html
                topMargin: ui.du(2)
                horizontalAlignment: HorizontalAlignment.Left
            }
            Label {
                text: qsTr("App icon is based on the <a href='https://thenounproject.com/term/ninja/110907'>Ninja icon</a> by Christian Mohr from the Noun Project.", "Content of the 'Credits' help section.") + Retranslate.onLocaleOrLanguageChanged
                multiline: true
                textFormat: TextFormat.Html
                topMargin: ui.du(2)
                horizontalAlignment: HorizontalAlignment.Left
            }
            Label {
                text: qsTr("The Android robot icon is modified from work created by Google and used according to the <a href='http://creativecommons.org/licenses/by/3.0/us/'>Creative Commons 3.0 Attribution License</a>.", "Content of the 'Credits' help section.") + Retranslate.onLocaleOrLanguageChanged
                multiline: true
                textFormat: TextFormat.Html
                topMargin: ui.du(2)
                horizontalAlignment: HorizontalAlignment.Left
            }
        }
    }
}
