import bb.cascades 1.4
import com.anmipo.blackberry.appninja 1.0
import "Globals.js" as Globals

Page {
    property string titleTemplate // main part of the page title, e.g. "All Apps"
    property int filterType   // see FilterCriteria::Type
    property int dataSize: -1 // updated after each search
    property bool searchMode: false
    property bool menuEnabled: true
    
    function refreshSearchResults() {
        searchMode = (searchTextField.text.length > 0);
        var dataModel = appListView.dataModel;
        dataModel.filter.text = searchTextField.text; // updates the results
        dataSize = dataModel.size();
    }
    
    onFilterTypeChanged: {
        appListView.dataModel.filter.type = filterType;
    }
    onCreationCompleted: {
        searchTextField.requestFocus();
    }
    
    titleBar: TitleBar {
        // Localized text with the dynamic translation and locale updates support
        title: (searchMode ? 
            qsTr("%n apps found", "Title of the search results page. %n is the number of apps. Please provide plural forms, too.", dataSize) 
            : (titleTemplate + " (%1)").arg(dataSize)) + Retranslate.onLocaleOrLanguageChanged
    }
    Container {
        layout: DockLayout { }
        ListView {
            id: appListView

            dataModel: _app.getDataModel()
            scrollRole: ScrollRole.Main
            visible: (dataSize != 0)
            listItemComponents: [
                ListItemComponent {
                    type: "header"
                    Header {
                        title: ListItemData
                    }
                },
                ListItemComponent {
                    type: "item"
                    StandardListItem {
                        title: ListItemData.applicationName
                        description: ListItemData.packageAuthor
                        status: ListItemData.packageVersion
                        imageSource: "file://" + ListItemData.absoluteIconPath
                        imageSpaceReserved: true
                    }
                }
            ]
            onTriggered: {
                if (indexPath.length > 1) { // ignore headers
                    showAppInfoPage(dataModel.data(indexPath));
                }
            }
        }
        Container {
            layout: StackLayout { }
            visible: searchMode && (dataSize == 0)
            horizontalAlignment: HorizontalAlignment.Center
            verticalAlignment: VerticalAlignment.Center
            ImageView {
                imageSource: "asset:///images/search_splash.png"
                horizontalAlignment: HorizontalAlignment.Center
            }
            Label {
                text: qsTr("Nothing found", "Text shown when no apps match the given search query") + Retranslate.onLocaleOrLanguageChanged
                horizontalAlignment: HorizontalAlignment.Center
                verticalAlignment: VerticalAlignment.Bottom
            }
        }
    }
    
    paneProperties: NavigationPaneProperties {
        backButton: ActionItem {
            title: qsTr("Back", "Button to return to previous page") + Retranslate.onLocaleOrLanguageChanged
        }
    }
    
    actions: [
        ActionItem {
            title: qsTr("Refresh", "A button/action to reload app list") + Retranslate.onLocaleOrLanguageChanged
            ActionBar.placement: ActionBarPlacement.InOverflow
            imageSource: "asset:///images/ic_refresh.png"
            onTriggered: {
                _app.refresh();
                refreshSearchResults();
            }
        },
        InvokeActionItem {
            title: qsTr("Share List", "A button to export list to another app") + Retranslate.onLocaleOrLanguageChanged
            imageSource: "asset:///images/ic_share.png"
            ActionBar.placement: ActionBarPlacement.InOverflow
            query {
                mimeType: "text/plain"
                invokeActionId: "bb.action.SHARE"
            }
            onTriggered: {
                data = _app.getAppListAsText();
            }
        },
        InvokeActionItem {
            title: qsTr("Review AppNinja", "A button/action to post a review of AppNinja in BlackBerry World") + Retranslate.onLocaleOrLanguageChanged
            imageSource: "asset:///images/ic_rate_app.png"
            ActionBar.placement: ActionBarPlacement.InOverflow
            query {
                invokeTargetId: "sys.appworld"
                invokeActionId: "bb.action.OPEN"
                uri: Globals.selfReviewUri
            }
        },
        TextInputActionItem {
            id: searchTextField
            title: qsTr("Search", "Title of the search query input field") + Retranslate.onLocaleOrLanguageChanged
            input.flags: TextInputFlag.SpellCheckOff
            input.submitKey: SubmitKey.Search
            imageSource: "asset:///images/ic_search.png"
            hintText: qsTr("Enter search text here", "Call for action inside the search query input field") + Retranslate.onLocaleOrLanguageChanged
            onTextChanging: {
                refreshSearchResults();
            }
            input.onSubmitted: {
                if (dataSize == 0) {
                    //nothing found, keep editing the query
                } else if (dataSize == 1) {
                    // one thing found, just open it
                    var dm = appListView.dataModel;
                    var firstResult = dm.data(dm.first());
                    showAppInfoPage(firstResult);
                } else {
                    // many things found, let the user choose one
                    appListView.requestFocus();
                } 
            }
        }
    ]
}
