import bb.cascades 1.4
import com.anmipo.blackberry.appninja 1.0
import "Globals.js" as Globals

Page {
    property bool menuEnabled: false
    
    titleBar: TitleBar {
        title: qsTr("Settings", "Title of the settings page") + Retranslate.onLocaleOrLanguageChanged
    }

    actions: [
        ActionItem {
            title: qsTr("Support", "A button/action to write an email to the application developer") + Retranslate.onLocaleOrLanguageChanged
            imageSource: "asset:///images/ic_email.png"
            ActionBar.placement: ActionBarPlacement.Signature
            onTriggered: {
                _app.invokeEmailComposer(
                    Globals.feedbackEmail, 
                    qsTr("AppNinja (v%1) - Support request", "Subject line for support email. %1 is the version number").arg(Application.applicationVersion), 
                    "\n\n" + _app.getPlatformDescription());
            }
        },
        ActionItem {
            title: qsTr("Review", "A button/action to post a review of AppNinja in BB World.") + Retranslate.onLocaleOrLanguageChanged
            imageSource: "asset:///images/ic_rate_app.png"
            ActionBar.placement: ActionBarPlacement.OnBar
            onTriggered: {
                selfReviewInvocation.trigger(selfReviewInvocation.query.invokeActionId);
            }
        }
    ]
    
    ScrollView {
        scrollRole: ScrollRole.Main
        horizontalAlignment: HorizontalAlignment.Fill
        verticalAlignment: VerticalAlignment.Fill
        Container {
            verticalAlignment: VerticalAlignment.Fill
            horizontalAlignment: HorizontalAlignment.Fill
            leftPadding: ui.du(2)
            rightPadding: ui.du(2)
            topPadding: ui.du(2)
            bottomPadding: ui.du(2)
            DropDown {
                id: themeSelector
                
                onSelectedValueChanged: {
                    if (selectedValue) {
                        _settings.visualStyle = selectedValue;
                        
                        // Ok, this is very weird, but setting the visual style
                        // without this check leads to a segfault... Reasons unknown.
                        if (selectedValue != Application.themeSupport.theme.colorTheme.style) {
                            Application.themeSupport.setVisualStyle(selectedValue);
                        }
                    }
                }
                
                title: qsTr("Color Theme", "Selector of app color theme (bright/dark)") + Retranslate.onLocaleOrLanguageChanged
                options: [
                    Option {
                        text: qsTr("Dark", "App color theme option.") + Retranslate.onLocaleOrLanguageChanged
                        selected: (_settings.visualStyle == VisualStyle.Dark)
                        value: VisualStyle.Dark
                    },
                    Option {
                        text: qsTr("Bright", "App color theme option.") + Retranslate.onLocaleOrLanguageChanged
                        selected: (_settings.visualStyle == VisualStyle.Bright)
                        value: VisualStyle.Bright
                    }
                ]
            }
            DropDown {
                id: startFilterSelector
                title: qsTr("Startup View", "Drop-down selector of the page to show on app start (for example, 'Startup View: Native Apps').") + Retranslate.onLocaleOrLanguageChanged
                topMargin: ui.du(2)
                bottomMargin: ui.du(2)
                onSelectedValueChanged: {
                    if (selectedOption) {
                        _settings.startupTabIndex = selectedValue;
                    }
                }
                options: [
                    Option {
                        text: Globals.strings.allApps + Retranslate.onLocaleOrLanguageChanged
                        selected: (_settings.startupTabIndex == value)
                        value: 0
                    },
                    Option {
                        text: Globals.strings.systemApps + Retranslate.onLocaleOrLanguageChanged
                        selected: (_settings.startupTabIndex == value)
                        value: 1
                    },
                    Option {
                        text: Globals.strings.thirdPartyApps + Retranslate.onLocaleOrLanguageChanged
                        selected: (_settings.startupTabIndex == value)
                        value: 2
                    },
                    // Tab #3 is just a divider
                    Option {
                        text: Globals.strings.nativeApps + Retranslate.onLocaleOrLanguageChanged
                        selected: (_settings.startupTabIndex == value)
                        value: 4
                    },
                    Option {
                        text: Globals.strings.androidApps + Retranslate.onLocaleOrLanguageChanged
                        selected: (_settings.startupTabIndex == value)
                        value: 5
                    },
                    Option {
                        text: Globals.strings.webworksApps + Retranslate.onLocaleOrLanguageChanged
                        selected: (_settings.startupTabIndex == value)
                        value: 6
                    }
                ]
            }
            Header {
                title: qsTr("Summary Fields", "Title of the settings section with a list of fields to show in the 'Summary' tab") + Retranslate.onLocaleOrLanguageChanged
            }
            CheckBox {
                text: qsTr("Author Name", "Settings check box = show Author Name field in app Summary tab") + Retranslate.onLocaleOrLanguageChanged
                checked: _settings.showSummaryPackageAuthor
                onCheckedChanged: {
                    _settings.showSummaryPackageAuthor = checked;
                }
            }
            CheckBox {
                text: qsTr("Application Description", "Settings check box = show App Description field in app Summary tab") + Retranslate.onLocaleOrLanguageChanged
                checked: _settings.showSummaryApplicationDescription
                onCheckedChanged: {
                    _settings.showSummaryApplicationDescription = checked;
                }
            }
            CheckBox {
                text: qsTr("Application Origins", "Settings check box = show application origins field in app Summary tab") + Retranslate.onLocaleOrLanguageChanged
                checked: _settings.showSummaryInstallationSource
                onCheckedChanged: {
                    _settings.showSummaryInstallationSource = checked;
                }
            }
            CheckBox {
                text: qsTr("Package Name", "Settings check box = show Package Name field in app Summary tab") + Retranslate.onLocaleOrLanguageChanged
                checked: _settings.showSummaryPackageName
                onCheckedChanged: {
                    _settings.showSummaryPackageName = checked;
                }
            }
            CheckBox {
                text: qsTr("Package Version", "Settings check box = show Package Version field in app Summary tab") + Retranslate.onLocaleOrLanguageChanged
                checked: _settings.showSummaryPackageVersion
                onCheckedChanged: {
                    _settings.showSummaryPackageVersion = checked;
                }
            }
            CheckBox {
                text: qsTr("Package Issue Date", "Settings check box = show package creation date field in app Summary tab.") + Retranslate.onLocaleOrLanguageChanged
                checked: _settings.showSummaryPackageIssueDate
                onCheckedChanged: {
                    _settings.showSummaryPackageIssueDate = checked;
                }
            }
        }
    }
}
