/*
 * Copyright (c) 2011-2015 BlackBerry Limited.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import bb.cascades 1.4
import bb.system 1.2
import com.anmipo.blackberry.appninja 1.0
import "Globals.js" as Globals

TabbedPane {

    // Opens detailed page for the given app info
    function showAppInfoPage(appInfo) {
        var appInfoPageComponent = Qt.createComponent("AppInfoPage.qml");
        var appInfoPage = appInfoPageComponent.createObject(null, {"appInfo": appInfo});
        naviPane.push(appInfoPage);
    }

    function refreshTab() {
        appListPage.titleTemplate = activeTab.title;
        appListPage.filterType = activeTab.filterType;
        appListPage.refreshSearchResults();
    }
    
    function showScanError(message) {
        scanErrorDialog.body = message;
        scanErrorDialog.show();
    }

    function complainAboutError(errorTitle, errorBody) {
        var messageBody = qsTr("Hello,\n\n" + 
                "AppNinja just showed me an error message:\n\"%1\" - \"%2\"\n" +
                "What can I do?\n\n" +
                "%3\n", "Email template with bug report. %1 and %2 are error details, %3 is device details. Please preserve the empty lines.") // placeholder for platform description
                .arg(errorTitle)
                .arg(errorBody)
                .arg(_app.getPlatformDescription()) 
                + Retranslate.onLocaleOrLanguageChanged;
        _app.invokeEmailComposer(
                Globals.feedbackEmail,
                qsTr("AppNinja (v%1) - Error", "Subject line of a bug report email. %1 will be replaced with version number)").arg(Application.applicationVersion),
                messageBody);
    }
        
    onCreationCompleted: {
        _app.scanError.connect(showScanError);
        _app.scanStarted.connect(busyToast.show);
        _app.scanFinished.connect(function () {
            refreshTab(); 
            busyToast.cancel();
        });
        
        var startupTab = at(_settings.startupTabIndex);
        if (activeTab == startupTab) {
            refreshTab(); // still need to update the (current) tab
        } else {
            activeTab = startupTab;
        }
        
        if (_settings.isFeedbackTime())
        	feedbackDialog.show();
    }    
    
    onActiveTabChanged: {
        refreshTab();
    }

    activePane: NavigationPane {
        id: naviPane
        
        onPushTransitionEnded: {
            Application.menuEnabled = page.menuEnabled
        }
        onPopTransitionEnded: {
            page.destroy();
            Application.menuEnabled = top.menuEnabled;
        }
        
        AppListPage {
            id: appListPage
        }
    }

    Tab {
        property int filterType: FilterCriteria.FIND_ALL_APPS
        title: Globals.strings.allApps + Retranslate.onLocaleOrLanguageChanged
        imageSource: "asset:///images/ic_all_apps.png"
        delegateActivationPolicy: TabDelegateActivationPolicy.None
    }
    Tab {
        property int filterType: FilterCriteria.FIND_SYSTEM_APPS
        title: Globals.strings.systemApps + Retranslate.onLocaleOrLanguageChanged
        imageSource: "asset:///images/ic_system_apps.png"
        delegateActivationPolicy: TabDelegateActivationPolicy.None
    }
    Tab {
        property int filterType: FilterCriteria.FIND_THIRD_PARTY_APPS
        title: Globals.strings.thirdPartyApps + Retranslate.onLocaleOrLanguageChanged
        imageSource: "asset:///images/ic_third_party_apps.png"
        delegateActivationPolicy: TabDelegateActivationPolicy.None
    }
    Tab { // divider item
        title: ""
        enabled: false
        imageSource: "asset:///images/empty.png"
    }
    Tab {
        property int filterType: FilterCriteria.FIND_NATIVE_ONLY
        title: Globals.strings.nativeApps + Retranslate.onLocaleOrLanguageChanged
        imageSource: "asset:///images/ic_cascades.png"
        delegateActivationPolicy: TabDelegateActivationPolicy.None
    }
    Tab {
        property int filterType: FilterCriteria.FIND_ANDROID_ONLY
        title: Globals.strings.androidApps + Retranslate.onLocaleOrLanguageChanged
        imageSource: "asset:///images/ic_android.png"
        delegateActivationPolicy: TabDelegateActivationPolicy.None
    }
    Tab {
        property int filterType: FilterCriteria.FIND_WEBWORKS_ONLY
        title: Globals.strings.webworksApps + Retranslate.onLocaleOrLanguageChanged
        imageSource: "asset:///images/ic_webworks.png"
        delegateActivationPolicy: TabDelegateActivationPolicy.None
    }
    
    Menu.definition: MenuDefinition {
        helpAction: HelpActionItem {
            title: qsTr("About") + Retranslate.onLocaleOrLanguageChanged
            imageSource: "asset:///images/ic_info.png"
            onTriggered: {
                var aboutPage = aboutPageComponent.createObject();
                naviPane.push(aboutPage);
            }
            attachedObjects: [
                ComponentDefinition {
                    id: aboutPageComponent
                    AboutPage { }
                }
            ]
        }
        settingsAction: SettingsActionItem {
            onTriggered: {
                var settingsPage = settingsPageComponent.createObject();
                naviPane.push(settingsPage);
            }
            attachedObjects: [
                ComponentDefinition {
                    id: settingsPageComponent
                    SettingsPage { }
                }
            ]
        }
    }
    attachedObjects: [
        SystemProgressToast {
            id: busyToast
            body: qsTr("Updating...", "Status message/progress popup while refreshing app list.") + Retranslate.onLocaleOrLanguageChanged
        },
        SystemDialog {
            id: scanErrorDialog
            title: qsTr("Loading Error", "Title of an error notification popup, failure to load/refresh app list") + Retranslate.onLocaleOrLanguageChanged
            cancelButton.label: ""
            confirmButton.label: qsTr("Report Problem", "A button/action to compose an email to the developer with the details of encountered app error") + Retranslate.onLocaleOrLanguageChanged
            dismissAutomatically: false  // prevent closing, since there is no remedy anyway
            onFinished: {
                complainAboutError(scanErrorDialog.title, scanErrorDialog.body);
            }
        },
        SystemDialog {
            id: feedbackDialog
            body: qsTr("Do you like AppNinja?", "Question to the user, with Yes/No replies") + Retranslate.onLocaleOrLanguageChanged
            cancelButton.label: qsTr("Yes", "Do you like this app?") + Retranslate.onLocaleOrLanguageChanged
            confirmButton.label: qsTr("No", "Do you like this app?") + Retranslate.onLocaleOrLanguageChanged
            onFinished: {
                if (value == SystemUiResult.ConfirmButtonSelection) {
                    var messageBody = qsTr("Hello,\n\nI don't like AppNinja because... \n\n%1\n", "Email text template. %1 will be replaced with device info. Please preserve the empty lines.")
                         .arg(_app.getPlatformDescription()) 
                         + Retranslate.onLocaleOrLanguageChanged;
                    _app.invokeEmailComposer(
                         Globals.feedbackEmail,
                         qsTr("AppNinja (v%1) - Feedback", "Subject line of an email with user feedback/complaints").arg(Application.applicationVersion),
                         messageBody);
                } else if (value == SystemUiResult.CancelButtonSelection) {
                    selfReviewInvocation.trigger(selfReviewInvocation.query.invokeActionId);
                }
            }
        },
        Invocation { // Invokes BBW to review AppNinja
            id: selfReviewInvocation
            query {
                invokeTargetId: "sys.appworld"
                invokeActionId: "bb.action.OPEN"
                uri: Globals.selfReviewUri
            }
        }
    ]
}
